==> ejc-scientific-impl-3.0.0-20250304.072520-21-sources.jar: com/ejianc/business/scientific/sci/bean/SciProjectUserEntity.java <==
package com.ejianc.business.scientific.sci.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 科研项目立项-项目成员
 * 
 * @author generator
 * 
 */
 @TableName("ejc_scientific_project_user")
public class SciProjectUserEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="pid")
    private Long pid; // 主表主键
    @TableField(value="user_id")
    private Long userId; // 人员主键
    @TableField(value="user_name")
    private String userName; // 人员名称
    @TableField(value="user_mobile")
    private String userMobile; // 联系方式
    @TableField(value="post_id")
    private Long postId; // 职务主键
    @TableField(value="post_name")
    private String postName; // 职务名称
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="professional")
    private String professional; // 职称
    @TableField(value="duty")
    private String duty; // 课题内职务
    @TableField(value="plan_hour")
    private BigDecimal planHour; // 计划工时(月)
    @TableField(value="source_id")
    private Long sourceId; // 来源主键
    
    
    

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }
    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }
    public String getUserMobile() {
        return userMobile;
    }

    public void setUserMobile(String userMobile) {
        this.userMobile = userMobile;
    }
    public Long getPostId() {
        return postId;
    }

    public void setPostId(Long postId) {
        this.postId = postId;
    }
    public String getPostName() {
        return postName;
    }

    public void setPostName(String postName) {
        this.postName = postName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getProfessional() {
        return professional;
    }

    public void setProfessional(String professional) {
        this.professional = professional;
    }
    public String getDuty() {
        return duty;
    }

    public void setDuty(String duty) {
        this.duty = duty;
    }
    public BigDecimal getPlanHour() {
        return planHour;
    }

    public void setPlanHour(BigDecimal planHour) {
        this.planHour = planHour;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    
}

==> ejc-scientific-impl-3.0.0-20250307.104000-48-sources.jar: com/ejianc/business/scientific/sci/bean/SciProjectUserEntity.java <==
package com.ejianc.business.scientific.sci.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 科研项目立项-项目成员
 * 
 * @author generator
 * 
 */
 @TableName("ejc_scientific_project_user")
public class SciProjectUserEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="pid")
    private Long pid; // 主表主键
    @TableField(value="user_id")
    private Long userId; // 人员主键
    @TableField(value="user_name")
    private String userName; // 人员名称
    @TableField(value="user_mobile")
    private String userMobile; // 联系方式
    @TableField(value="post_id")
    private Long postId; // 职务主键
    @TableField(value="post_name")
    private String postName; // 职务名称
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="professional")
    private String professional; // 职称
    @TableField(value="duty")
    private String duty; // 课题内职务
    @TableField(value="plan_hour")
    private BigDecimal planHour; // 计划工时(月)
    @TableField(value="source_id")
    private Long sourceId; // 来源主键

    @TableField(exist=false)
    @SubEntity(serviceName="sciProjectUserHourService")//此处有pid="xxx"，默认值pid="pid"
    private List<SciProjectUserHourEntity> hourList = new ArrayList<>(); // 科研项目立项-项目成员-计划工时
    

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }
    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }
    public String getUserMobile() {
        return userMobile;
    }

    public void setUserMobile(String userMobile) {
        this.userMobile = userMobile;
    }
    public Long getPostId() {
        return postId;
    }

    public void setPostId(Long postId) {
        this.postId = postId;
    }
    public String getPostName() {
        return postName;
    }

    public void setPostName(String postName) {
        this.postName = postName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getProfessional() {
        return professional;
    }

    public void setProfessional(String professional) {
        this.professional = professional;
    }
    public String getDuty() {
        return duty;
    }

    public void setDuty(String duty) {
        this.duty = duty;
    }
    public BigDecimal getPlanHour() {
        return planHour;
    }

    public void setPlanHour(BigDecimal planHour) {
        this.planHour = planHour;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }

    public List<SciProjectUserHourEntity> getHourList() {
        return hourList;
    }

    public void setHourList(List<SciProjectUserHourEntity> hourList) {
        this.hourList = hourList;
    }
}
